
# This file was generated by 'versioneer.py' (0.29) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-11-27T10:13:57+0100",
 "dirty": true,
 "error": null,
 "full-revisionid": "dfd8a8692cccd4cfa6e968b69944dd38e1d2af5d",
 "version": "0.2.7"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
